This documents LearnerRegrBam and
LearnerClassifBam that allow for mgcv::bam to be used in
mlr3 without explicitly loading mlr3extralearners. See
ml_gKRLS for examples of how to use this and mlr3 for
discussion of the "Learner" objects.
mlr3::Learner -> mlr3::LearnerRegr -> LearnerRegrBam
new()Creates a new instance of this [R6][R6::R6Class] class.
LearnerRegrBam$new()
clone()The objects of this class are cloneable with this method.
LearnerRegrBam$clone(deep = FALSE)deepWhether to make a deep clone.
mlr3::Learner -> mlr3::LearnerClassif -> LearnerClassifBam
Wood, Simon N and Goude, Yannig and Simon Shaw. 2015. "Generalized Additive Models for Large Data Sets." Journal of the Royal Statistical Society: Series C (Applied Statistics) 64(1):139-155.